tiled.client.base.BaseClient
============================

.. currentmodule:: tiled.client.base

.. autoclass:: BaseClient

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~BaseClient.__init__
      ~BaseClient.new_variation
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~BaseClient.context
      ~BaseClient.item
      ~BaseClient.metadata
      ~BaseClient.offline
      ~BaseClient.path
      ~BaseClient.uri
      ~BaseClient.username
   
   